@@ -5,7 +5,7 @@ use warnings;
 use base 'My::Builder';
 
 use File::Spec::Functions qw(catdir catfile rel2abs);
-use My::Utility qw(check_header check_prereqs_libs check_prereqs_tools);
+use My::Utility qw(check_header check_prereqs_libs check_prereqs_tools $inc_lib_candidates);
 use Config;
 use Capture::Tiny;
 
@@ -14,20 +14,6 @@ if($^O eq 'cygwin') {
   $My::Utility::cc = 'gcc';
 }
 
-my $inc_lib_candidates = {
-  '/usr/local/include'       => '/usr/local/lib',
-  '/usr/local/include/smpeg' => '/usr/local/lib',
-  '/usr/pkg/include'         => '/usr/pkg/lib',
-};
-
-$inc_lib_candidates->{'/usr/pkg/include/smpeg'}   = '/usr/local/lib' if -f '/usr/pkg/include/smpeg/smpeg.h';
-#$inc_lib_candidates->{'/usr/local/include/smpeg'} = '/usr/local/lib' if -f '/usr/local/include/smpeg/smpeg.h';
-$inc_lib_candidates->{'/usr/include/smpeg'}       = '/usr/lib'       if -f '/usr/include/smpeg/smpeg.h';
-$inc_lib_candidates->{'/usr/X11R6/include'}       = '/usr/X11R6/lib' if -f '/usr/X11R6/include/GL/gl.h';
-#$inc_lib_candidates->{'/usr/local/include'}       = '/usr/local/lib' if -f '/usr/local/include/png.h';
-#$inc_lib_candidates->{'/usr/local/include'}       = '/usr/local/lib' if -f '/usr/local/include/tiff.h';
-#$inc_lib_candidates->{'/usr/local/include'}       = '/usr/local/lib' if -f '/usr/local/include/jpeglib.h';
-
 sub get_additional_cflags {
   my $self = shift;
   my @list = ();
@@ -44,7 +30,7 @@ sub get_additional_libs {
   my @list = ();
   my %rv; # putting detected dir into hash to avoid duplicates
   for (keys %$inc_lib_candidates) {
-    my $ld = $inc_lib_candidates->{$_};
+    my $ld       = $inc_lib_candidates->{$_};
     $rv{"-L$ld"} = 1 if ((-d $_) && (-d $ld));
   }
   push @list, (keys %rv);
@@ -61,8 +47,7 @@ sub build_binaries {
   my( $self, $build_out, $build_src ) = @_;
   my $bp = $self->notes('build_params');
   foreach my $pack (@{$bp->{members}}) {
-    if(($pack->{pack} =~ m/^(png)$/ && check_prereqs_libs($pack->{pack}))
-    || ($pack->{pack} =~ m/^zlib$/  && check_prereqs_libs('z'))) {
+    if($pack->{pack} =~ m/^png|ogg|vorbis|z$/ && check_prereqs_libs($pack->{pack})->[0]) {
       print "SKIPPING package '" . $pack->{dirname} . "' (already installed)...\n";
     }
     elsif($pack->{pack} =~ m/^(SDL_mixer)$/ && !$self->_is_gnu_make($self->_get_make)) {
@@ -76,15 +61,31 @@ sub build_binaries {
     }
     else {
       print "BUILDING package '" . $pack->{dirname} . "'...\n";
-      my $srcdir = catfile($build_src, $pack->{dirname});
+      my $srcdir    = catfile($build_src, $pack->{dirname});
       my $prefixdir = rel2abs($build_out);
       $self->config_data('build_prefix', $prefixdir); # save it for future Alien::SDL::ConfigData
 
       chdir $srcdir;
 
+      if($pack->{pack} eq 'SDL' && $^O eq 'cygwin') {
+        $self->do_system('cp ../../patches/SDL-1.2.14-configure configure');
+        $self->do_system('cp ../../patches/SDL-1.2.14-ltmain_sh build-scripts/ltmain.sh');
+      }
+
+      # setting environments PATH
+      my $extra_PATH = "";
+      if ($^O eq 'solaris') {
+        # otherwise we get "false cru build/libSDLmain.a build/SDL_dummy_main.o"
+        # see http://fixunix.com/ntp/245613-false-cru-libs-libopts-libopts_la-libopts-o.html#post661558
+        for (qw[/usr/ccs/bin /usr/xpg4/bin /usr/sfw/bin /usr/xpg6/bin /usr/gnu/bin /opt/gnu/bin /usr/bin]) {
+          $extra_PATH .= ":$_" if -d $_;
+        }
+      }
+      $ENV{PATH} = "$prefixdir/bin:$ENV{PATH}$extra_PATH";
+
       # do './configure ...'
       my $run_configure = 'y';
-      $run_configure = $self->prompt("Run ./configure for '$pack->{pack}' again?", "y") if (-f "config.status");
+      $run_configure    = $self->prompt("Run ./configure for '$pack->{pack}' again?", "y") if (-f "config.status");
       if (lc($run_configure) eq 'y') {
         my $cmd = $self->_get_configure_cmd($pack->{pack}, $prefixdir);
         print "Configuring package '$pack->{pack}'...\n";
@@ -99,7 +100,7 @@ sub build_binaries {
         }
       }
 
-      $self->do_system('cp ../SDL-1.2.14/libtool libtool') if $pack->{pack} eq 'SDL_Pango';
+      $self->do_system('cp ../SDL-1.2/libtool libtool') if $pack->{pack} eq 'SDL_Pango';
 
       # do 'make install'
       my @cmd = ($self->_get_make, 'install');
@@ -118,23 +119,24 @@ sub build_binaries {
 sub _get_configure_cmd {
   my ($self, $pack, $prefixdir) = @_;
   my $extra                     = '';
-  my $extra_cflags              = "-I$prefixdir/include";
-  my $extra_ldflags             = "-L$prefixdir/lib";
+  my $escaped_prefixdir         = $self->escape_path( $prefixdir );
+  my $extra_cflags              = "-I$escaped_prefixdir/include" . $self->get_additional_cflags();
+  my $extra_ldflags             = "-L$escaped_prefixdir/lib"     . $self->get_additional_libs();
   my $extra_PATH                = "";
   my $uname                     = $Config{archname};
   my $stdout                    = '';
   my $stderr                    = '';
   my $cmd;
-  
+
   ($stdout, $stderr) = Capture::Tiny::capture { print `uname -a`; };
-  $uname .= " $stdout" if $stdout;
+  $uname            .= " $stdout" if $stdout;
 
   # NOTE: all ugly IFs concerning ./configure params have to go here
 
   if($pack eq 'SDL_gfx' && $uname =~ /(powerpc|ppc|64|2level|alpha|armv5|sparc)/i) {
     $extra .= ' --disable-mmx';
   }
-  
+
   if($pack eq 'SDL' && $uname =~ /(powerpc|ppc)/) {
     $extra .= ' --disable-video-ps3';
   }
@@ -156,8 +158,12 @@ sub _get_configure_cmd {
     $extra .= ' --disable-audio';
   }
 
+  if($pack eq 'SDL' && $^O eq 'openbsd') {
+    $extra_ldflags .= ' -lpthread';
+  }
+
   if($pack =~ /^SDL_/) {
-    $extra .= " --with-sdl-prefix=$prefixdir";
+    $extra .= " --with-sdl-prefix=$escaped_prefixdir";
   }
 
   if($pack =~ /^SDL/ && -d '/usr/X11R6/lib' && -d '/usr/X11R6/include') {
@@ -165,9 +171,23 @@ sub _get_configure_cmd {
     $extra_ldflags .= ' -L/usr/X11R6/lib';
   }
 
-  if(($pack eq 'SDL') && ($^O eq 'cygwin')) {
-    # kmx experienced troubles while cygwin build when nasm was present in PATH
-    $extra .= " --disable-nasm";
+  if($^O eq 'cygwin') {
+    #$extra_cflags  .= " -I/lib/gcc/i686-pc-cygwin/3.4.4/include";
+    #$extra_ldflags .= " -L/lib/gcc/i686-pc-cygwin/3.4.4";
+#    $extra_cflags  .= " -I/usr/include";
+#    $extra_ldflags .= " -L/lib";
+#    $extra_cflags  .= " -I/lib/gcc/i686-pc-cygwin/4.3.4/include";
+#    $extra_ldflags .= " -L/lib/gcc/i686-pc-cygwin/4.3.4";
+
+    if($pack eq 'SDL') {
+      # kmx experienced troubles while cygwin build when nasm was present in PATH
+#      $extra .= " --disable-nasm --enable-pthreads --enable-pthread-sem --enable-sdl-dlopen --disable-arts"
+#              . " --disable-esd --disable-nas --enable-oss --disable-pulseaudio --disable-dga --disable-video-aalib"
+#              . " --disable-video-caca --disable-video-dga --enable-video-dummy --disable-video-ggi --enable-video-opengl"
+#              . " --enable-video-x11 --disable-video-x11-dgamouse --disable-video-x11-vm --enable-video-x11-xinerama"
+#              . " --disable-video-x11-xme --enable-video-x11-xrandr --disable-video-x11-xv --disable-arts-shared"
+#              . " --disable-esd-shared --disable-pulseaudio-shared --enable-x11-shared";
+    }
   }
 
   if($pack eq 'jpeg') {
@@ -175,14 +195,6 @@ sub _get_configure_cmd {
     $extra .= " --disable-ld-version-script";
   }
 
-  # otherwise we get "false cru build/libSDLmain.a build/SDL_dummy_main.o"
-  # see http://fixunix.com/ntp/245613-false-cru-libs-libopts-libopts_la-libopts-o.html#post661558
-  if ($^O eq 'solaris') {
-    for (qw[/usr/ccs/bin /usr/xpg4/bin /usr/sfw/bin /usr/xpg6/bin /usr/gnu/bin /opt/gnu/bin /usr/bin]) {
-      $extra_PATH .= ":$_" if -d $_;
-    }
-  }
-
   ### This was intended as a fix for http://www.cpantesters.org/cpan/report/7064012
   ### Unfortunately does not work.
   #
@@ -192,28 +204,29 @@ sub _get_configure_cmd {
   #  $extra_ldflags .= ' -L/usr/X11R6/lib';
   #}
 
-  if($pack =~ /^zlib/) {
+  if($pack eq 'z') {
     # does not support params CFLAGS=...
-    $cmd = "./configure --prefix=$prefixdir";
+    $cmd = "./configure --prefix=$escaped_prefixdir";
   }
   else {
-    $cmd = "./configure --prefix=$prefixdir --enable-static=no --enable-shared=yes $extra" .
+    $cmd = "./configure --prefix=$escaped_prefixdir --enable-static=yes --enable-shared=yes $extra" .
            " CFLAGS=\"$extra_cflags\" LDFLAGS=\"$extra_ldflags\"";
   }
 
-  if($pack ne 'SDL' && $^O eq 'openbsd') {
-    $cmd = "LD_LIBRARY_PATH=\"$prefixdir/lib:\$LD_LIBRARY_PATH\" $cmd";
+  if($pack ne 'SDL' && $^O =~ /^openbsd|gnukfreebsd$/) {
+    $cmd = "LD_LIBRARY_PATH=\"$escaped_prefixdir/lib:\$LD_LIBRARY_PATH\" $cmd";
   }
 
-  # we need to have $prefixdir/bin in PATH while running ./configure
-  $cmd = "PATH=\"$prefixdir/bin:\$PATH$extra_PATH\" $cmd";
+  if($pack eq 'vorbis') {
+    $cmd = "PKG_CONFIG_PATH=\"$escaped_prefixdir/lib/pkgconfig:\$PKG_CONFIG_PATH\" $cmd";
+  }
 
   return $cmd;
 }
 
 sub _get_make {
   my ($self) = @_;
-  my @try = ('make', 'gmake', $Config{gmake}, $Config{make});
+  my @try    = ('make', 'gmake', $Config{gmake}, $Config{make});
   my %tested;
   print "Gonna detect GNU make:\n";
   foreach my $name ( @try ) {
@@ -221,7 +234,7 @@ sub _get_make {
     next if $tested{$name};
     $tested{$name} = 1;
     print "- testing: '$name'\n";
-    if ($self->_is_gnu_make($name)) {
+    if($self->_is_gnu_make($name)) {
       print "- found: '$name'\n";
       return $name
     }
@@ -232,12 +245,19 @@ sub _get_make {
 
 sub _is_gnu_make {
   my ($self, $name) = @_;
-  my $devnull = File::Spec->devnull();
-  my $ver = `$name --version 2> $devnull`;
-  if ($ver =~ /GNU Make/i) {
+  my $devnull       = File::Spec->devnull();
+  my $ver           = `$name --version 2> $devnull`;
+  if($ver =~ /GNU Make/i) {
     return 1;
   }
   return 0;
 }
 
+sub escape_path {
+  my( $self, $path ) = @_;
+  my $_path          = $path;
+  $_path             =~ s/([^\\]) /$1\\ /g;
+  return $_path;
+}
+
 1;
