@@ -43,7 +43,7 @@ my $prebuilt_binaries = [
       sha1sum  => '98409ddeb649024a9cc1ab8ccb2ca7e8fe804fd8',
       arch_re  => qr/^MSWin32-x86-multi-thread$/,
       os_re    => qr/^MSWin32$/,
-      cc_re    => qr/gcc|cl/,
+      cc_re    => qr/gcc/,
     },
     {
       title    => "Binaries Win/32bit SDL-1.2.14 (extended, 20111205)\n" .
@@ -55,7 +55,7 @@ my $prebuilt_binaries = [
       sha1sum  => '553b7e21bb650d047ec9f2a5f650c67d76430e61',
       arch_re  => qr/^MSWin32-x86-multi-thread$/,
       os_re    => qr/^MSWin32$/,
-      cc_re    => qr/gcc|cl/,
+      cc_re    => qr/gcc/,
     },
     {
       title    => "Binaries Win/64bit SDL-1.2.14 (extended, 20100824)\n" .
@@ -69,7 +69,7 @@ my $prebuilt_binaries = [
       sha1sum  => 'ccffb7218bcb17544ab00c8a1ae383422fe9586d',
       arch_re  => qr/^MSWin32-x64-multi-thread$/,
       os_re    => qr/^MSWin32$/,
-      cc_re    => qr/gcc|cl/,
+      cc_re    => qr/gcc/,
       gccversion_re => qr/^4\.4\.3$/, #specific to the old gcc compiler used in 64bit strawberryperl 5.12.x
     },
     {
@@ -82,9 +82,20 @@ my $prebuilt_binaries = [
       sha1sum  => '35f3b496ca443a9d14eff77e9e26acfa813afafd',
       arch_re  => qr/^MSWin32-x64-multi-thread$/,
       os_re    => qr/^MSWin32$/,
-      cc_re    => qr/gcc|cl/,
+      cc_re    => qr/gcc/,
       gccversion_re => qr/^4\.(4\.[5-9]|[5-9]\.[0-9])$/,
     },
+    {
+      title    => "Binaries Win/32bit SDL-1.2.15 (20120612)\n" .
+                  "\t(gfx, image, mixer, smpeg, ttf)",
+      url      => [
+        'http://froggs.de/libsdl/Win32_SDL-1.2.15-20120612.zip',
+      ],
+      sha1sum  => '22c531c1d0cc5a363c05045760870b2f45e9d0da',
+      arch_re  => qr/^MSWin32/,
+      os_re    => qr/^MSWin32$/,
+      cc_re    => qr/cl/,
+    },
  ];
 
 #### tarballs with source codes
@@ -174,6 +185,7 @@ our $source_packs = [
         sha1sum  => 'ec9841377403e8d1bcfd76626434be64d11f59f0',
         patches => [
           'test1.patch',
+          'SDL-1.2-openbsd-rldflags.patch',
         ],
         prereqs => {
           libs => [
@@ -219,7 +231,9 @@ our $source_packs = [
           'http://froggs.de/libsdl/libvorbis-1.3.3.tar.gz',
         ],
         sha1sum  => '8dae60349292ed76db0e490dc5ee51088a84518b',
-        patches => [ ],
+        patches => [
+          'libvorbis-1.3.3-configure.patch',
+        ],
         prereqs => {
           libs => [ ]
         }
@@ -352,6 +366,7 @@ sub check_prereqs_libs {
 
   foreach my $lib (@libs) {
     print "checking for $lib... ";
+    my $found_dll          = '';
     my $found_lib          = '';
     my $found_inc          = '';
     my $header_map         = {
@@ -367,6 +382,8 @@ sub check_prereqs_libs {
     foreach (keys %$inc_lib_candidates) {
       my $ld = $inc_lib_candidates->{$_};
       next unless -d $_ && -d $ld;
+      ($found_dll) = find_file($ld, qr/[\/\\]lib\Q$lib\E[\-\d\.]*\.($dlext[\d\.]*|so|dll)$/);
+      $found_dll   = $1 if $found_dll && $found_dll =~/^(.+($dlext|so|dll))/ && -e $1;
       ($found_lib) = find_file($ld, qr/[\/\\]lib\Q$lib\E[\-\d\.]*\.($dlext[\d\.]*|a|dll.a)$/);
       ($found_inc) = find_file($_,  qr/[\/\\]\Q$header\E[\-\d\.]*\.h$/);
       last if $found_lib && $found_inc;
@@ -383,8 +400,8 @@ sub check_prereqs_libs {
 
     if( scalar(@libs) == 1 ) {
       return $ret
-        ? (get_header_version($found_inc) || 'found')
-        : 0;
+        ? [(get_header_version($found_inc) || 'found'), $found_dll]
+        : [0, undef];
     }
   }
 
